==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/LostFocusEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LostFocusEventArgsDescription } from "./LostFocusEventArgsDescription";
/**
 * @hidden
 */
export let LostFocusEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class LostFocusEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (LostFocusEventArgsDescriptionMetadata.a == null) {
                LostFocusEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LostFocusEventArgsDescriptionMetadata.c(LostFocusEventArgsDescriptionMetadata.a);
            }
            if (a.k(LostFocusEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(LostFocusEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            LostFocusEventArgsDescriptionMetadata.b(a);
            a.ad("LostFocusEventArgs", () => new LostFocusEventArgsDescription());
            a.ac("LostFocusEventArgs", LostFocusEventArgsDescriptionMetadata.a);
        }
    }
    LostFocusEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(LostFocusEventArgsDescriptionMetadata, 'LostFocusEventArgsDescriptionMetadata');
    LostFocusEventArgsDescriptionMetadata.a = null;
    return LostFocusEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/LostFocusEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LostFocusEventArgsDescription } from "./LostFocusEventArgsDescription";
/**
 * @hidden
 */
export let LostFocusEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class LostFocusEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (LostFocusEventArgsDescriptionMetadata.a == null) {
                LostFocusEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LostFocusEventArgsDescriptionMetadata.c(LostFocusEventArgsDescriptionMetadata.a);
            }
            if (a.k(LostFocusEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(LostFocusEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            LostFocusEventArgsDescriptionMetadata.b(a);
            a.ae("LostFocusEventArgs", () => new LostFocusEventArgsDescription());
            a.ad("LostFocusEventArgs", LostFocusEventArgsDescriptionMetadata.a);
        }
    }
    LostFocusEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(LostFocusEventArgsDescriptionMetadata, 'LostFocusEventArgsDescriptionMetadata');
    LostFocusEventArgsDescriptionMetadata.a = null;
    return LostFocusEventArgsDescriptionMetadata;
})();
